# Point-Scanning Super-Resolution (**PSSR**)

**PSSR** is a standardized [PyTorch](https://pytorch.org)-based workflow for super-resolution tasks using microscopy images.
This is the official reimplementation of the methods described in the original paper: [Deep learning-based point-scanning super-resolution imaging](https://www.nature.com/articles/s41592-021-01080-z),
containing various improvements and new features.

The **PSSR** User Guide and full API Reference is available in the [PSSR Documentation](https://ucsdmanorlab.github.io/PSSR).

If you have never used **PSSR** before, [Getting Started](https://ucsdmanorlab.github.io/PSSR/guide/start.html) outlines installation and basic usage.
Full reference and explanations of all **PSSR** tools is available in [API Reference](https://ucsdmanorlab.github.io/PSSR/reference/api.html).

This package is under continuous development. All code can be found at [https://github.com/ucsdmanorlab/PSSR](https://github.com/ucsdmanorlab/PSSR).
If you experience any bugs, unexpected behaviors, or have any suggestions, make sure to [open a ticket](https://github.com/ucsdmanorlab/PSSR/issues).
